@@ -21,6 +21,11 @@ class BaseRowClient:
         r = requests.get(url=db_url, headers={'Authorization': f'JWT {self.br_jwt_token}'})
         return r.json()
 
+    def list_fields(self, br_table_id):
+        url = f"{self.br_base_url}database/fields/table/{br_table_id}/"
+        r = requests.get(url, headers={'Authorization': f'JWT {self.br_jwt_token}'})
+        return r.json()
+
     def yield_rows(self, br_table_id, filters={}):
         br_rows_url = f"{self.br_base_url}database/rows/table/{br_table_id}/"
         url = f"{br_rows_url}?user_field_names=true"
